<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import InputSelect from '@/components/input-select'
import {
  couponForm,
  couponSearchForm,
  getActivityEffectiveTime,
  getActivityReceiveTime,
  couponColumn,
} from '@/utils/coupon-form'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/v2/coupon/avtivy/page',
        newUrl: 'flower/api/v2/coupon/avtivy',
        viewUrl: 'flower/api/v2/coupon/avtivy',
        viewOnPath: true,
        editUrl: 'flower/api/v2/coupon/avtivy',
        editMethodType: 'put',
        editOnPath: true,
        deleteUrl: 'flower/api/v2/coupon/avtivy',
        deleteMethodType: 'delete',
        deleteOnPath: true,
        canEdit: (row) => row.status === 'inactive' || row.status === 'expired',
        canDelete: (row) =>
          row.status === 'inactive' || row.status === 'expired',
        operationAttrs: {
          width: 180,
          fixed: 'right',
        },
        onResetView: (row) => {
          this.$router.push(`${this.$route.path}/${row.id}`)
        },
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            row.usageTypeStr = getActivityEffectiveTime(row)
            row.getStartDateStr = getActivityReceiveTime(row)
          }
        },
        columns: [
          ...couponColumn(),
          {
            label: '优惠券图片',
            formatter: (row) => (
              <el-bus-image
                style="width:50px;height:50px"
                lazy={true}
                src={row.imageUrl}
              />
            ),
          },
          {
            label: '领取时间',
            formatter: getActivityReceiveTime,
            minWidth: 320,
          },
          {
            label: '有效期',
            formatter: getActivityEffectiveTime,
            minWidth: 320,
          },
          { label: '领取渠道', prop: 'getTypeName', minWidth: 120 },
          { label: '已领取总数', prop: 'getNum', minWidth: 150 },
          { label: '剩余未领取总数', prop: 'unGetNum', minWidth: 150 },
          { label: '状态', prop: 'statusName', minWidth: 120 },
          { label: '领取渠道', prop: 'getTypeName', minWidth: 120 },
          { label: '操作人', prop: 'createByName', minWidth: 120 },
        ],
        // 页面上要到分，后端要传到秒
        beforeConfirm: (data) => {
          if (data.getStartDate) {
            data.getStartDate = this.$elBusUtil.formatDate(
              data.getStartDate,
              'YYYY-MM-DD HH:mm:ss'
            )
          }
          if (data.getEndDate) {
            data.getEndDate = this.$elBusUtil.formatDate(
              data.getEndDate,
              'YYYY-MM-DD HH:mm:ss'
            )
          }
          if (data.usageStartDate) {
            data.usageStartDate = this.$elBusUtil.formatDate(
              data.usageStartDate,
              'YYYY-MM-DD HH:mm:ss'
            )
          }
          if (data.usageEndDate) {
            data.usageEndDate = this.$elBusUtil.formatDate(
              data.usageEndDate,
              'YYYY-MM-DD HH:mm:ss'
            )
          }
        },
        searchForm: [
          {
            type: 'row',
            items: [...couponSearchForm(),
              {
                label: '领取渠道：',
                id: 'getType',
                type: 'bus-select-dict',
                el: {
                  code: 'COUPON_GET_TYPE',
                  style: 'width:100%',
                },
              },
            ],
          },

        ],
        form: [
          ...couponForm(),
          {
            label: '领取渠道：',
            id: 'getType',
            type: 'bus-select-dict',
            el: {
              code: 'COUPON_GET_TYPE',
              style: 'width:100%',
            },
            str: true,
            strKey: 'getTypeName',
            rules: { required: true, message: '请选择领取渠道' },
            on: {
              change: (e, updateForm,obj) => {
    
                if(e[0]==='home'){
                  // 如果是首页领取的话，则图片为必传递
                  this.updateImageUrlRules(this.tableConfig.form,"imageUrl",true,"图片为必填项目")
                }else{
                  this.updateImageUrlRules(this.tableConfig.form,"imageUrl",false,"请输入图片")
                }
              },
            },

          },
          {
            label: '优惠券图片：',
            id: 'imageUrl',
            type: 'bus-upload',
            el: {
              listType: 'picture-card',
              limit: 1,
              limitSize: 2,
              tipText: '大小不超过2M',
              valueType: 'string',
            },
            forceDisabled: true,
            rules: {
              required: true,
              message: '请上传商品图片',
              trigger: 'blur',
            },
          },
          {
            label: '领取时间：',
            id: 'getStartDate',
            component: 'el-bus-date-range',
            el: {
              type: 'datetime',
              format: 'yyyy-MM-dd HH:mm',
              valueFormat: 'yyyy-MM-dd HH:mm',
            },
            str: true,
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['getStartDate', 'getEndDate'],
          },
          {
            label: '使用时间：',
            id: 'usageType',
            type: 'bus-select-dict',
            el: {
              code: 'COUPON_USAGE_TYPE',
              style: 'width:100%',
            },
            str: true,
            rules: { required: true, message: '请选择使用时间' },
            on: {
              change: (e, updateForm) => {
                updateForm({
                  usageStartDate: null,
                  usageEndDate: null,
                  usageTimeNum: undefined,
                  usageTimeType: null,
                })
              },
            },
          },
          {
            label: '使用固定时间：',
            id: 'usageStartDate',
            component: 'el-bus-date-range',
            el: {
              type: 'datetime',
              format: 'yyyy-MM-dd HH:mm',
              valueFormat: 'yyyy-MM-dd HH:mm',
            },
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['usageStartDate', 'usageEndDate'],
            hidden: (row, item, mode) =>
              row.usageType !== 'fixed' || mode === 'view',
          },
          {
            label: '领取后有效时间：',
            id: 'usageTimeNum',
            component: InputSelect,
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['usageTimeNum', 'usageTimeType'],
            el: {
              inputAttrs: {
                min: 1,
                max: 99999999,
                precision: 0,
                controls: false,
              },
              selectAttrs: {
                code: 'COUPON_USAGE_TIME_TYPE',
              },
            },
            hidden: (row, item, mode) =>
              row.usageType !== 'get_after_time' || mode === 'view',
          },
          {
            label: '发放数量：',
            id: 'couponAmount',
            type: 'input-number',
            el: {
              precision: 0,
              min: 1,
              max: 99999999,
              controls: false,
            },
            unit: '张',
            rules: {
              required: true,
              message: '请输入发放数量',
              trigger: 'blur',
            },
          },
          {
            label: '每人限领：',
            id: 'getLimit',
            type: 'input-number',
            el: {
              precision: 0,
              min: 1,
              max: 99999999,
              controls: false,
            },
            unit: '张',
            rules: {
              required: true,
              message: '请输入每人限领',
              trigger: 'blur',
            },
          },
        ],
        extraButtons: [
          {
            text: '发布',
            show: (row) =>
              row.status === 'inactive' || row.status === 'expired',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要发布吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/avtivy/active/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('发布成功')
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '下架',
            show: (row) => row.status === 'active',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要下架吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/avtivy/expire/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '活动优惠券',
    }
  },
  methods: {
    updateImageUrlRules(form,id,required,message) {
      const curField =form.find(
        (field) => field.id === id
      );
      if (curField && curField.rules && required) {
        curField.rules.required = true;
        curField.rules.message = message;
      }else if(curField && curField.rules){
        curField.rules.required = false;
        curField.rules.message = message;
      }
    },
  },
}
</script>
